#' Sample burndown dataset
#'
#' This is sample burndown dataset provided for testing.
#'
#' @name burndown
#' @docType data
#' @author Dan Kelley
#' @family things related to burndown data
#' @family data sets provided with plan
NULL


#' Sample gantt dataset
#'
#' This is sample gantt dataset provided for testing.
#'
#' @name gantt
#' @docType data
#' @author Dan Kelley
#' @family things related to gantt data
#' @family data sets provided with plan
NULL


#' Plan, a package for project planning
#'
#' This package provides tools for project planning, e.g. burndown charts,
#' gantt diagrams, etc.; see [burndown-class] and
#' [gantt-class] for entries to the documentation.
#'
#' @name plan
#' @docType package
#' @author Dan Kelley
#' @keywords internal
"_PACKAGE"
## usethis namespace: start
## usethis namespace: end
NULL

